OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "The last viewed note cannot be accessed. " : "No se puede acceder a la última nota consultada. ",
    "Encryption Error" : "Error de encripción",
    "Error" : "Error",
    "New note" : "Nota nueva",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hay notas sin salvar. ¡Al salir de la página perderá todos los cambios!",
    "Delete note" : "Borrar nota",
    "Saving failed!" : "¡Falla al guardar!",
    "_%n word_::_%n words_" : ["%n palabra","%n palabras"]
},
"nplurals=2; plural=(n != 1);");
